@@ -14,7 +14,7 @@
 #include <sendmail.h>
 #include "map.h"
 
-SM_RCSID("@(#)$Id: daemon.c,v 8.678 2007/03/08 00:33:40 ca Exp $")
+SM_RCSID("@(#)$Id: daemon.c,v 8.680 2008/02/14 00:20:26 ca Exp $")
 
 #if defined(SOCK_STREAM) || defined(__GNU_LIBRARY__)
 # define USE_SOCK_STREAM	1
@@ -1257,7 +1257,8 @@ setupdaemon(daemonaddr)
 #if NETINET
 	  case AF_INET:
 		if (daemonaddr->sin.sin_addr.s_addr == 0)
-			daemonaddr->sin.sin_addr.s_addr = INADDR_ANY;
+			daemonaddr->sin.sin_addr.s_addr =
+			    LocalDaemon ? htonl(INADDR_LOOPBACK) : INADDR_ANY;
 		port = daemonaddr->sin.sin_port;
 		break;
 #endif /* NETINET */
@@ -1265,7 +1266,8 @@ setupdaemon(daemonaddr)
 #if NETINET6
 	  case AF_INET6:
 		if (IN6_IS_ADDR_UNSPECIFIED(&daemonaddr->sin6.sin6_addr))
-			daemonaddr->sin6.sin6_addr = in6addr_any;
+			daemonaddr->sin6.sin6_addr =
+			    LocalDaemon ? in6addr_loopback : in6addr_any;
 		port = daemonaddr->sin6.sin6_port;
 		break;
 #endif /* NETINET6 */
@@ -2204,7 +2206,8 @@ makeconnection(host, port, mci, e, enough)
 #if NETINET
 		  case AF_INET:
 			if (clt_addr.sin.sin_addr.s_addr == 0)
-				clt_addr.sin.sin_addr.s_addr = INADDR_ANY;
+				clt_addr.sin.sin_addr.s_addr = LocalDaemon ?
+					htonl(INADDR_LOOPBACK) : INADDR_ANY;
 			else
 				clt_bind = true;
 			if (clt_addr.sin.sin_port != 0)
@@ -2215,7 +2218,8 @@ makeconnection(host, port, mci, e, enough)
 #if NETINET6
 		  case AF_INET6:
 			if (IN6_IS_ADDR_UNSPECIFIED(&clt_addr.sin6.sin6_addr))
-				clt_addr.sin6.sin6_addr = in6addr_any;
+				clt_addr.sin6.sin6_addr = LocalDaemon ?
+					in6addr_loopback : in6addr_any;
 			else
 				clt_bind = true;
 			socksize = sizeof(struct sockaddr_in6);
@@ -3274,7 +3278,7 @@ myhostname(hostbuf, size)
 	if (strchr(hostbuf, '.') == NULL &&
 	    !getcanonname(hostbuf, size, true, NULL))
 	{
-		sm_syslog(LOG_CRIT, NOQID,
+		sm_syslog(LocalDaemon ? LOG_WARNING : LOG_CRIT, NOQID,
 			  "My unqualified host name (%s) unknown; sleeping for retry",
 			  hostbuf);
 		message("My unqualified host name (%s) unknown; sleeping for retry",
@@ -3282,7 +3286,7 @@ myhostname(hostbuf, size)
 		(void) sleep(60);
 		if (!getcanonname(hostbuf, size, true, NULL))
 		{
-			sm_syslog(LOG_ALERT, NOQID,
+			sm_syslog(LocalDaemon ? LOG_WARNING : LOG_ALERT, NOQID,
 				  "unable to qualify my own domain name (%s) -- using short name",
 				  hostbuf);
 			message("WARNING: unable to qualify my own domain name (%s) -- using short name",
