@@ -13,7 +13,7 @@
 
 #include <sendmail.h>
 
-SM_RCSID("@(#)$Id: envelope.c,v 8.302 2006/11/10 23:12:52 ca Exp $")
+SM_RCSID("@(#)$Id: envelope.c,v 8.305 2008/03/31 16:32:13 ca Exp $")
 
 /*
 **  CLRSESSENVELOPE -- clear session oriented data in an envelope
@@ -105,9 +105,18 @@ newenvelope(e, parent, rpool)
 	e->e_parent = parent;
 	assign_queueid(e);
 	e->e_ctime = curtime();
+#if _FFR_SESSID
+	e->e_sessid = e->e_id;
+#endif /* _FFR_SESSID */
 	if (parent != NULL)
 	{
 		e->e_msgpriority = parent->e_msgsize;
+#if _FFR_SESSID
+		if (parent->e_sessid != NULL)
+			e->e_sessid = sm_rpool_strdup_x(rpool,
+							parent->e_sessid);
+#endif /* _FFR_SESSID */
+
 		if (parent->e_quarmsg == NULL)
 		{
 			e->e_quarmsg = NULL;
@@ -127,7 +136,7 @@ newenvelope(e, parent, rpool)
 	if (CurEnv->e_xfp != NULL)
 		(void) sm_io_flush(CurEnv->e_xfp, SM_TIME_DEFAULT);
 	if (sendmode != DM_NOTSET)
-		e->e_sendmode = sendmode;
+		set_delivery_mode(sendmode, e);
 
 	return e;
 }
